@@ -27,7 +27,7 @@ config.read_string(config_string)
 rpc_url = os.getenv('rpc_url', "http://127.0.0.1")
 # Get network type from enviroment variable or use default
 network = os.getenv('network', "")
-web_port = os.getenv('web_port', 8080)
+web_port = int(os.getenv('web_port', 8080))
 listening_ip = os.getenv('listening_ip', "127.0.0.1")
 
 # Get rpc user and password from configuration file
